@@ -28,6 +28,9 @@
 #include "object_cm_iso157652_rx_message.h"
 #include "object_vcan412_settings.h"
 #include "object_vividcan_settings.h"
+#include "object_fire2_device_status.h"
+#include "object_vcan4_device_status.h"
+#include "object_ics_device_status.h"
 
 #define _DOC_ICS_MODULE \
     "Python C Code module for interfacing to the icsneo40 dynamic library. Code tries\n" \
@@ -133,7 +136,10 @@ void initics(void)
     setup_cm_iso157652_tx_message_object(module);
     setup_cm_iso157652_rx_message_object(module);
     setup_vcan412_settings_object(module);
-	setup_vividcan_settings_object(module);
+    setup_vividcan_settings_object(module);
+    setup_fire2_device_status_object(module);
+    setup_vcan4_device_status_object(module); // 803+
+    setup_ics_device_status_object(module);
 
 #if PY_MAJOR_VERSION >= 3
     return module;
